# -----------------------------------------------------------------------------
#
#   Copyright (c) 1999-2002 by Klaus Reger <K.Reger@wwwdb.org>
#
#   You may distribute under the terms of either the GNU General Public
#   License or the Artistic License, as specified in the Perl README file.
#
#   THIS IS BETA SOFTWARE!
#
#   THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
#   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
#   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
#   $Id: AllTables.rc,v 1.1 2002/11/19 15:11:22 k_reger Exp $
#
# -----------------------------------------------------------------------------
# Program-Data
# -----------------------------------------------------------------------------
# Project  :
# System   :
# Program  :
# Module   : $RCSfile: AllTables.rc,v $
# Version  : $Revision: 1.1 $
# Date     : $Date: 2002/11/19 15:11:22 $
# State    : $State: Exp $
#
# Description:
#   Generate a site-map, using the categories and objects in the
#   database
#
# -----------------------------------------------------------------------------
# Change-log (See at end of this file)
# $Log: AllTables.rc,v $
# Revision 1.1  2002/11/19 15:11:22  k_reger
# - Generate config-files for all tables of current database
#
# Revision 1.1  2002/04/05 13:01:15  k_reger
# - New site-map
#
#
# --- Known Bugs -------------
# 
# --- TODO -------------------
# 
# ----------------------------------------------------------------------------

[Data]
Table     = ""
UpdFields = ""
QryFields = ""

IdField   = -

[Cache]
Timeout   = 0

[Browser]
MaxRows = 100

[Header]
Title = "All Tables for current Database"

[GUI]

[State All]
BtnCancel  = -
BtnHelp = -
BtnExit = -

[State Init]
Header = "Select a database-table"
BtnNew = -
BtnQry = -

[State Work]
BtnUpd = -
BtnDel = -
Header = ""

[State Qry]
Header = "-"
BtnFind = -

[Layout Label hr]
Pos = +1.+0+1.0
Type = Label
Text = "<HR>"

[Layout Label links]
Pos = +1.+0+1.0
Type = Label
SafeText = Yes
VAlign = Top
Text = ""
