#
# This is a Template-File for WWWdb
#
#
#

# --- Description of the data to access -----------------------------------------
[Data]
Table    = AppRc
Order    =

UpdFields = DbTable, Database
QryFields =

IdField   = dummy

[Cache]
Timeout         = 0

# --- Configuring the browser here ----------------------------------------------
[Browser]
MaxRows = 0

# --- General header for WWWdb --------------------------------------------------
[Header]
Title = "Create WWWdb-Applications - Step 1: Select database-table"

# --- Definition of the different states ----------------------------------------

# Buttons for all states
# please note that "-" deactivates a Button
[State All]
BtnHelp    = -
BtnCancel = Cancel.png
BtnExit = Exit.png

# This is the state when the form is called the first time, or the Back-button
# is pressed
[State Init]
Header = ""
BtnNew = -
BtnQry = -
BtnPrev = Prev.png
BtnNext = Next.png

# In this state you have selected a record, which you can update or delete
[State Work]
Header = ""
BtnUpd = -
BtnDel = -

# This is the record-Browser
[State Qry]
Header = ""

# --- Layout for the area, the data is shown ------------------------------------
[Layout Table]


[Layout Label ExplainText]
Pos  = +1.0+1.0
Text = <<EOF

<P>

Welcome to the <B>WWWdb</B>-application-configuration-file-wizard. It
allows you, to create application-config-files, using a WWW-interface.

</P>

<P>

First of all, we have to decide, which <B>database-table</B> we
need.

</P>

<P>

Please select one of the given tables:

</P>

<HR>
EOF

[Layout Label Database]
Text = "Database: "
Pos  = +1.0.0
Align = right

[Layout Field Database]
Pos  = +0.+1.0
Type = Label
Bold = 1
Values = ""


[Layout Label DbTable]
Text = "Database-Table: "
Pos  = +1.0.0
Align = right

[Layout Field DbTable]
Pos  = +0.+1.0
Type = Select
Values = ""
NoUndef = 1

[Layout Label ForceCreation]
Text = "Force Creation of a new config-file: "
Pos  = +1.0.0
Align = right

[Layout Field ForceCreation]
Pos  = +0.+1.0
Type = Checkbutton
Text = ""



[Layout Label Ruler]
Pos  = +1.0+1.0
Text = "<HR>"




