[DB]
# Driver for Interbase / Firebird
Driver    = InterBase

Username  = <DB_USER>
Password  = <DB_PASS>

Host      = <DB_HOST>
Database  = <ENV_INTERBASE_DB>/<DB_NAME>.gdb

DatePrintFormat = "%d/%m/%Y %H:%M"














